@@ -1,4 +1,3 @@
-import html
 from typing import Any, Iterable, List, NamedTuple, Optional, Union
 
 import htmlgenerator as hg
@@ -291,9 +290,8 @@ class DataTable(hg.TABLE):
         )
 
     @staticmethod
-    def from_model(
-        model,
-        queryset=None,
+    def from_queryset(
+        queryset,
         # column behaviour
         columns: Iterable[Union[str, "DataTableColumn"]] = (),
         prevent_automatic_sortingnames=False,
@@ -325,6 +323,7 @@ class DataTable(hg.TABLE):
                               difficutl to add another button by modifying the
                               datatable after creation.
         """
+        model = queryset.model
         columns = columns or filter_fieldlist(model, ["__all__"])
 
         title = title or pretty_modelname(model, plural=True)
@@ -365,7 +364,6 @@ class DataTable(hg.TABLE):
                 style="display: flex; justify-content: flex-end;",
             )
 
-        queryset = model.objects.all() if queryset is None else queryset
         column_definitions: List[DataTableColumn] = []
         for col in columns:
             if not (isinstance(col, DataTableColumn) or isinstance(col, str)):
@@ -440,17 +438,6 @@ class DataTable(hg.TABLE):
             settingspanel=settingspanel,
         )
 
-    @staticmethod
-    def from_queryset(
-        queryset,
-        **kwargs,
-    ):
-        return DataTable.from_model(
-            queryset.model,
-            queryset=queryset,
-            **kwargs,
-        )
-
     # A few helper classes to make the composition in the __init__ method easier
 
     @staticmethod
@@ -536,9 +523,7 @@ def searchbar(search_urlparameter: str):
         widgetattributes={
             "autofocus": True,
             "name": search_urlparameter,
-            "value": hg.F(
-                lambda c: html.escape(c["request"].GET.get(search_urlparameter, ""))
-            ),
+            "value": hg.F(lambda c: c["request"].GET.get(search_urlparameter, "")),
             "onfocus": "this.setSelectionRange(this.value.length, this.value.length);",
         }
     )
