@@ -91,7 +91,7 @@ class BrowseView(BreadView, LoginRequiredMixin, PermissionListMixin, ListView):
     itemsperpage_urlparameter: str = "itemsperpage"
     search_urlparameter: str = "q"
 
-    title: Optional[hg.BaseElement] = None
+    title: Union[hg.BaseElement, str] = ""
     columns: Iterable[Union[str, layout.datatable.DataTableColumn]] = ("__all__",)
     rowclickaction: Optional[Link] = None
     # bulkactions: List[(Link, function(request, queryset))]
@@ -162,9 +162,8 @@ class BrowseView(BreadView, LoginRequiredMixin, PermissionListMixin, ListView):
             for action in self.bulkactions
             if action.has_permission(self.request)
         ]
-        return layout.datatable.DataTable.from_model(
-            self.model,
-            hg.C("object_list"),
+        return layout.datatable.DataTable.from_queryset(
+            self.get_queryset(),
             columns=self.columns,
             bulkactions=bulkactions,
             rowactions=self.rowactions,
